@@ -96,6 +96,7 @@ typedef struct
   char *sm_config_prefix;
 
   guint zoom_set : 1;
+  guint wait : 1;
 } TerminalOptions;
 
 typedef struct
@@ -177,9 +178,9 @@ void terminal_fprintf (FILE* fp,
 #define terminal_print_detail(...) terminal_print_level(DETAIL, __VA_ARGS__)
 #define terminal_print_debug(...) terminal_print_level(DEBUG, __VA_ARGS__)
 
-#define terminal_printerr_detail(...) terminal_print_level(DETAIL, __VA_ARGS__)
-#define terminal_printerr(...) terminal_print_level(NORMAL, __VA_ARGS__)
-#define terminal_printerr_debug(...) terminal_print_level(DEBUG, __VA_ARGS__)
+#define terminal_printerr_detail(...) terminal_printerr_level(DETAIL, __VA_ARGS__)
+#define terminal_printerr(...) terminal_printerr_level(NORMAL, __VA_ARGS__)
+#define terminal_printerr_debug(...) terminal_printerr_level(DEBUG, __VA_ARGS__)
 
 #if GLIB_CHECK_VERSION (2, 50, 0)
 GLogWriterOutput terminal_log_writer (GLogLevelFlags log_level,
