@@ -230,7 +230,7 @@ precompile_regexes (const TerminalRegexPattern *regex_patterns,
       GError *error = NULL;
 
       (*regexes)[i] = vte_regex_new_for_match (regex_patterns[i].pattern, -1,
-                                               PCRE2_UTF | PCRE2_NO_UTF_CHECK | PCRE2_MULTILINE,
+                                               PCRE2_UTF | PCRE2_NO_UTF_CHECK | PCRE2_UCP | PCRE2_MULTILINE,
                                                &error);
       g_assert_no_error (error);
 
@@ -829,6 +829,13 @@ terminal_screen_profile_changed_cb (GSettings     *profile,
   vte_terminal_set_delete_binding (vte_terminal,
                                    g_settings_get_enum (profile, TERMINAL_PROFILE_DELETE_BINDING_KEY));
 
+  if (!prop_name || prop_name == I_(TERMINAL_PROFILE_ENABLE_BIDI_KEY))
+    vte_terminal_set_enable_bidi (vte_terminal,
+                                  g_settings_get_boolean (profile, TERMINAL_PROFILE_ENABLE_BIDI_KEY));
+  if (!prop_name || prop_name == I_(TERMINAL_PROFILE_ENABLE_SHAPING_KEY))
+    vte_terminal_set_enable_shaping (vte_terminal,
+                                     g_settings_get_boolean (profile, TERMINAL_PROFILE_ENABLE_SHAPING_KEY));
+
   if (!prop_name || prop_name == I_(TERMINAL_PROFILE_ALLOW_BOLD_KEY))
     vte_terminal_set_allow_bold (vte_terminal,
                                  g_settings_get_boolean (profile, TERMINAL_PROFILE_ALLOW_BOLD_KEY));
